package WebGUI::i18n::Dutch::Asset_Product;
use utf8;
our $I18N = {
  10 => {
    'lastUpdated' => '1152839002',
    'message' => '<p>Prijs</p>'
  },
  '10 description' => {
    'lastUpdated' => '1213711681',
    'message' => 'De prijs van deze variant.<br /> '
  },
  13 => {
    'lastUpdated' => '1152885918',
    'message' => 'Brochure'
  },
  '13 description' => {
    'lastUpdated' => '1152885932',
    'message' => 'De brochure van dit product'
  },
  14 => {
    'lastUpdated' => '1152885952',
    'message' => 'Handleiding'
  },
  '14 description' => {
    'lastUpdated' => '1152885991',
    'message' => 'De product-, gebruikers-, of onderhoudshandleiding van dit product. '
  },
  15 => {
    'lastUpdated' => '1152886347',
    'message' => 'Garantie'
  },
  '15 description' => {
    'lastUpdated' => '1152886368',
    'message' => 'De garantie op dit product'
  },
  16 => {
    'lastUpdated' => '1152886456',
    'message' => 'Voeg een accessoire toe'
  },
  17 => {
    'lastUpdated' => '1152886476',
    'message' => 'Accessoire'
  },
  '17 description' => {
    'lastUpdated' => '1152886643',
    'message' => 'Kies uit de lijst met producten die u al heeft ingevoerd'
  },
  18 => {
    'lastUpdated' => '1152886668',
    'message' => 'Een andere accessoire toevoegen? '
  },
  '18 description' => {
    'lastUpdated' => '1152886688',
    'message' => 'Kies &#39;ja&#39; als u een andere accessoire wilt toevoegen.'
  },
  19 => {
    'lastUpdated' => '1152890164',
    'message' => 'Voeg een verwant product toe'
  },
  2 => {
    'lastUpdated' => '1152890690',
    'message' => 'Weet u zeker dat u de link met dit accessoire wilt verwijderen?'
  },
  20 => {
    'lastUpdated' => '1152890731',
    'message' => 'Verwant product'
  },
  '20 description' => {
    'lastUpdated' => '1152890756',
    'message' => 'Kies uit de lijst met producten die u al heeft toegevoegd.'
  },
  21 => {
    'lastUpdated' => '1152899051',
    'message' => 'Een ander verwant product toevoegen?'
  },
  '21 description' => {
    'lastUpdated' => '1152899087',
    'message' => 'Kies &#39;ja&#39; als u een ander verwant product wilt toevoegen. '
  },
  22 => {
    'lastUpdated' => '1152899646',
    'message' => 'Bewerk eigenschap'
  },
  23 => {
    'lastUpdated' => '1152899662',
    'message' => 'Eigenschap'
  },
  '23 description' => {
    'lastUpdated' => '1152899851',
    'message' => 'U kunt een nieuwe eigenschap invoeren, of kiezen uit een lijst voor een ander product in het systeem'
  },
  24 => {
    'lastUpdated' => '1152899869',
    'message' => 'Een andere eigenschap toevoegen? '
  },
  '24 description' => {
    'lastUpdated' => '1152903899',
    'message' => 'Als u direct een andere eigenschap wilt toevoegen, kies &#39;ja&#39;. '
  },
  25 => {
    'lastUpdated' => '1152918641',
    'message' => 'Bewerk specificatie'
  },
  26 => {
    'lastUpdated' => '1152918654',
    'message' => 'Label'
  },
  '26 description' => {
    'lastUpdated' => '1152918967',
    'message' => 'Het type specificatie. Bijvoorbeeld, hoogte, gewicht, of kleur. U kunt er een kiezen die u al voor een ander product heeft ingevoerd, of een nieuwe specificatie schrijven.  '
  },
  27 => {
    'lastUpdated' => '1153081642',
    'message' => 'Specificatie'
  },
  '27 description' => {
    'lastUpdated' => '1153081924',
    'message' => 'De actuele waarde van de specificatie. Bijvoorbeeld, als u hoogte als label kiest, dan kunt u een waarde invoeren zoals &#39;18&#39;.'
  },
  28 => {
    'lastUpdated' => '1153087956',
    'message' => '<p>Een andere specificatie toevoegen?</p>'
  },
  '28 description' => {
    'lastUpdated' => '1153087989',
    'message' => 'Als u een andere specificatie wilt toevoegen, kies &#39;ja&#39;.'
  },
  29 => {
    'lastUpdated' => '1153088032',
    'message' => 'Eenheden'
  },
  '29 description' => {
    'lastUpdated' => '1153088653',
    'message' => 'De meeteenheid voor deze specificatie. Bijvoorbeeld, als u hoogte al label heeft gekozen, is de eenheid wellicht &#39;meter&#39;.  '
  },
  3 => {
    'lastUpdated' => '1153088673',
    'message' => 'Weet u zeker dat u deze eigenschap wilt verwijderen?'
  },
  30 => {
    'lastUpdated' => '1153088776',
    'message' => 'Eigenschappen'
  },
  31 => {
    'lastUpdated' => '1153088786',
    'message' => 'Specificaties'
  },
  32 => {
    'lastUpdated' => '1153088796',
    'message' => 'Accessoires'
  },
  33 => {
    'lastUpdated' => '1153088808',
    'message' => 'Verwante producten'
  },
  34 => {
    'lastUpdated' => '1153088819',
    'message' => 'Voeg een eigenschap toe'
  },
  35 => {
    'lastUpdated' => '1153090153',
    'message' => 'Voeg een specificatie toe'
  },
  36 => {
    'lastUpdated' => '1153090201',
    'message' => 'Voeg een accessoire toe '
  },
  37 => {
    'lastUpdated' => '1153090219',
    'message' => 'Voeg een verwant product toe '
  },
  4 => {
    'lastUpdated' => '1153152419',
    'message' => 'Weet u zeker dat u de link naar dit verwante product wilt verwijderen? '
  },
  48 => {
    'lastUpdated' => '1153230570',
    'message' => 'Weet u zeker dat u dit voordeel wil verwijderen? Het kan na verwijdering niet worden teruggehaald. '
  },
  5 => {
    'lastUpdated' => '1153233224',
    'message' => 'Weet u zeker dat u deze specificatie wilt verwijderen? '
  },
  51 => {
    'lastUpdated' => '1153234059',
    'message' => 'Voordeel'
  },
  '51 description' => {
    'lastUpdated' => '1153234115',
    'message' => 'U kunt een nieuw voordeel invoeren, of kiezen uit welke u al heeft toegevoegd. '
  },
  52 => {
    'lastUpdated' => '1153234206',
    'message' => 'Een ander voordeel toevoegen?'
  },
  '52 description' => {
    'lastUpdated' => '1153234233',
    'message' => 'Als u meteen een ander voordeel wilt toevoegen, kies &#39;ja&#39; '
  },
  53 => {
    'lastUpdated' => '1153234246',
    'message' => 'Bewerk voordeel'
  },
  54 => {
    'lastUpdated' => '1153234256',
    'message' => 'Voordelen'
  },
  55 => {
    'lastUpdated' => '1153234276',
    'message' => 'Een voordeel toevoegen '
  },
  56 => {
    'lastUpdated' => '1153234299',
    'message' => 'Een product-sjabloon toevoegen'
  },
  57 => {
    'lastUpdated' => '1153234367',
    'message' => 'Weet u zeker dat u dit sjabloon wilt verwijderen en alle producten die het gebruiken instellen op het standaard-sjabloon? '
  },
  58 => {
    'lastUpdated' => '1153234395',
    'message' => 'Bewerk product-sjabloon'
  },
  59 => {
    'lastUpdated' => '1153234413',
    'message' => 'Naam'
  },
  6 => {
    'lastUpdated' => '1153234426',
    'message' => 'Bewerk product'
  },
  60 => {
    'lastUpdated' => '1153234441',
    'message' => 'Sjabloon '
  },
  62 => {
    'lastUpdated' => '1153234492',
    'message' => 'Product-sjabloon'
  },
  '62 description' => {
    'lastUpdated' => '1153234610',
    'message' => 'Kies een lay-out voor dit product'
  },
  7 => {
    'lastUpdated' => '1153234984',
    'message' => 'Product-afbeelding 1 '
  },
  '7 description' => {
    'lastUpdated' => '1153235001',
    'message' => 'Een afbeelding van dit product'
  },
  8 => {
    'lastUpdated' => '1153235011',
    'message' => 'Product-afbeelding 2'
  },
  '8 description' => {
    'lastUpdated' => '1153235029',
    'message' => 'Een afbeelding van dit product '
  },
  9 => {
    'lastUpdated' => '1153235043',
    'message' => 'Product-afbeelding 3'
  },
  '9 description' => {
    'lastUpdated' => '1153235058',
    'message' => 'Een afbeelding van dit product '
  },
  'Controls' => {
    'lastUpdated' => '1250240869',
    'message' => 'Beheerfuncties'
  },
  'Lost' => {
    'lastUpdated' => '1302247963',
    'message' => 'Asset verloren'
  },
  'accessory_controls' => {
    'lastUpdated' => '1213711742',
    'message' => 'De WebGUI beheer functies voor deze accessoire.'
  },
  'accessory_loop' => {
    'lastUpdated' => '1153235614',
    'message' => 'Deze loop bevat alle accessoires die aan dit product gerelateerd zijn'
  },
  'accessory_title' => {
    'lastUpdated' => '1213711771',
    'message' => 'De titel van de bijbehorende accessoire.'
  },
  'accessory_url' => {
    'lastUpdated' => '1213711791',
    'message' => 'Het URL naar de bijbehorende accessoire'
  },
  'add a variant' => {
    'lastUpdated' => '1213711802',
    'message' => 'Voeg een variant toe'
  },
  'add another variant' => {
    'lastUpdated' => '1213711816',
    'message' => 'Nog een variant toevoegen?'
  },
  'add another variant description' => {
    'lastUpdated' => '1213714567',
    'message' => 'Als je nu direct nog een variant wilt toevoegen, kies dan &quot;Ja&quot;.'
  },
  'add to cart' => {
    'lastUpdated' => '1213711833',
    'message' => 'Toevoegen aan winkelwagen'
  },
  'add variant' => {
    'lastUpdated' => '1213711850',
    'message' => 'Voeg variant toe'
  },
  'addRelatedProduct_label' => {
    'lastUpdated' => '1213973683',
    'message' => 'Het vertaalde label voor de link toevoegen gerelateerd product.'
  },
  'addRelatedProduct_url' => {
    'lastUpdated' => '1213973710',
    'message' => 'Het URL om een gerelateerd product aan dit product toe te voegen.'
  },
  'addaccessory_label' => {
    'lastUpdated' => '1215444842',
    'message' => 'Het vertaalde label van de voeg toebehoren toe link'
  },
  'addaccessory_url' => {
    'lastUpdated' => '1215444869',
    'message' => 'Het URL voor het het toevoegen van een toebehoren aan dit product.'
  },
  'addbenefit_label' => {
    'lastUpdated' => '1215444979',
    'message' => 'Het vertaalde label voor de link &quot;Voordeel toevoegen&quot;.'
  },
  'addbenefit_url' => {
    'lastUpdated' => '1215445003',
    'message' => 'Het URL waar een voordeel toegevoegd wordt aan dit product.'
  },
  'addfeature_label' => {
    'lastUpdated' => '1215445035',
    'message' => 'Het vertaalde label voor de link &quot;Eigenschap toevoegen&quot;.'
  },
  'addfeature_url' => {
    'lastUpdated' => '1215445059',
    'message' => 'Het URl waar een eigenschap aan dit product wordt toegevoegd.'
  },
  'addspecification_label' => {
    'lastUpdated' => '1215445087',
    'message' => 'Het vertaalde label voor de link &quot; Specificatie toevoegen&quot;.'
  },
  'addspecification_url' => {
    'lastUpdated' => '1215445117',
    'message' => 'Het URL waar een specificatie toegevoegd wordt aan dit product.'
  },
  'addvariant_label' => {
    'lastUpdated' => '1215445353',
    'message' => 'Het vertaalde label voor de link &quot;Toevoegen variant&quot;.'
  },
  'addvariant_url' => {
    'lastUpdated' => '1215445377',
    'message' => 'Het URL waar nieuwe varianten van dit product kunnen worden toegevoegd.'
  },
  'assetName' => {
    'lastUpdated' => '1153237850',
    'message' => 'Product'
  },
  'benefit_benefit' => {
    'lastUpdated' => '1213711903',
    'message' => 'De tekst van het voordeel'
  },
  'benefit_controls' => {
    'lastUpdated' => '1213712239',
    'message' => 'De WebGUI beheer knoppen voor dit voordeel'
  },
  'benefit_loop' => {
    'lastUpdated' => '1153238442',
    'message' => 'Deze loop bevat de voordelen van dit product '
  },
  'brochure' => {
    'lastUpdated' => '1189367170',
    'message' => 'De unieke identificatie (ID) van het storage object voor de product-brochure.'
  },
  'brochure_icon' => {
    'lastUpdated' => '1215445408',
    'message' => 'Het URL naar het ikoontje van de brochure.'
  },
  'brochure_label' => {
    'lastUpdated' => '1215445426',
    'message' => 'Het vertaalde label voor het URL van de brochure.'
  },
  'brochure_url' => {
    'lastUpdated' => '1215445446',
    'message' => 'Het URL waar de brochure gedownload kan worden.'
  },
  'buy_form_button' => {
    'lastUpdated' => '1215444546',
    'message' => 'De invoer knop voor het formulier.'
  },
  'buy_form_footer' => {
    'lastUpdated' => '1215445513',
    'message' => 'HTML code om het formulier, waarop een variant aan de winkelwagen wordt toegevoegd, te beeindigen.'
  },
  'buy_form_header' => {
    'lastUpdated' => '1248782890',
    'message' => 'HTML code om het formulier, waarop een variant aan de winkelwagen wordt toegevoegd, te beginnen.'
  },
  'buy_form_options' => {
    'lastUpdated' => '1248782923',
    'message' => 'Een lijst met alle beschikbare varianten van dit product. Alleen producten met een voorraad worden getoond.'
  },
  'cache timeout' => {
    'lastUpdated' => '1153238847',
    'message' => 'Cache time-out'
  },
  'cache timeout help' => {
    'lastUpdated' => '1153240764',
    'message' => 'Omdat alle gebruikers deze asset op dezelfde manier zullen zien, kunnen we het langere tijd in de cache bewaren om de presentatie te verbeteren. Hoe lang moeten we het voor u in de cache bewaren?  '
  },
  'cacheTimeout' => {
    'lastUpdated' => '1189367193',
    'message' => 'De hoeveelheid tijd in seconden die de output van dit object (asset) wordt bewaard.'
  },
  'canEdit' => {
    'lastUpdated' => '1213973748',
    'message' => 'Een functie die waar is als de gebruiker dit product kan bewerken.'
  },
  'continueShoppingUrl' => {
    'lastUpdated' => '1216586127',
    'message' => 'Een URL waar de gebruiker verder kan gaan met winkelen.'
  },
  'default thank you message' => {
    'lastUpdated' => '1215516501',
    'message' => 'U wordt bedankt voor uw aankoop.'
  },
  'delete variant confirm' => {
    'lastUpdated' => '1213714596',
    'message' => 'Weet u zeker dat deze variant verwijderd moet worden?'
  },
  'deleteImage' => {
    'lastUpdated' => '1153239647',
    'message' => 'Verwijder bijgesloten bestand'
  },
  'feature_controls' => {
    'lastUpdated' => '1215444643',
    'message' => 'De WebGUI beheer knoppen voor deze eigenschap.'
  },
  'feature_feature' => {
    'lastUpdated' => '1215444884',
    'message' => 'De tekst van de eigenschap'
  },
  'feature_loop' => {
    'lastUpdated' => '1153240202',
    'message' => 'Deze loop bevat alle eigenschappen die aan dit product gerelateerd zijn '
  },
  'hasAddedToCart' => {
    'lastUpdated' => '1213716061',
    'message' => 'Een functie die aangeeft dat de gebruiker het product heeft toegevoegd aan de winkelwagen, zodat een bedankje getoond kan worden.'
  },
  'image1' => {
    'lastUpdated' => '1189367232',
    'message' => 'De unieke identificatie (ID) van het storage object van de eerste afbeelding die aan dit product is toegevoegd.'
  },
  'image2' => {
    'lastUpdated' => '1189367261',
    'message' => 'De unieke identificatie (ID) van het storage object van de tweede afbeelding die aan dit product is toegevoegd.'
  },
  'image3' => {
    'lastUpdated' => '1189367272',
    'message' => 'De unieke identificatie (ID) van het storage object van de derde afbeelding die aan dit product is toegevoegd.'
  },
  'in_stock' => {
    'lastUpdated' => '1213711945',
    'message' => 'Een functie die aangeeft of er varianten beschikbaar zijn voor de verkoop.'
  },
  'isShippingRequired' => {
    'lastUpdated' => '1218182632',
    'message' => 'Is verzenden vereist?'
  },
  'isShippingRequired help' => {
    'lastUpdated' => '1218182679',
    'message' => 'Dit bepaalt of verzendkosten berekend worden wanneer de gebruiker gaat afrekenen.'
  },
  'manual' => {
    'lastUpdated' => '1189367295',
    'message' => 'De unieke identificatie (ID) voor het storage object voor de handleiding van het product.'
  },
  'manual_icon' => {
    'lastUpdated' => '1215444569',
    'message' => 'Het URL naar het ikoontje van de handleiding'
  },
  'manual_label' => {
    'lastUpdated' => '1215444617',
    'message' => 'Het vertaalde label voor het URL van de handleiding.'
  },
  'manual_url' => {
    'lastUpdated' => '1215444593',
    'message' => 'Het URL waar de handleiding gedownload kan worden.'
  },
  'no_stock_message' => {
    'lastUpdated' => '1213974312',
    'message' => 'Een bericht waarin staat dat er geen varianten van dit product beschikbaar zijn voor de verkoop.'
  },
  'options' => {
    'lastUpdated' => '1213712286',
    'message' => 'Opties'
  },
  'other products' => {
    'lastUpdated' => '1213712274',
    'message' => 'Andere producten'
  },
  'out of stock' => {
    'lastUpdated' => '1213712254',
    'message' => 'Niet op voorraad'
  },
  'price' => {
    'lastUpdated' => '1189367305',
    'message' => 'De prijs van dit product.'
  },
  'product asset template variables body' => {
    'lastUpdated' => '1189367339',
    'message' => 'Elk object (asset) maakt een verzameling variabelen beschikbaar aan de bijbehorende templates gebaseerd op de interne kenmerken van het object. Sommige zijn bruikbaarder dan andere.'
  },
  'product asset template variables title' => {
    'lastUpdated' => '1189367353',
    'message' => 'Product object (asset) template variabelen'
  },
  'quantity' => {
    'lastUpdated' => '1213712108',
    'message' => 'Hoeveelheid'
  },
  'quantity description' => {
    'lastUpdated' => '1213974351',
    'message' => 'De hoeveelheid eenheden van deze variant die beschikbaar is.'
  },
  'relatedproduct_controls' => {
    'lastUpdated' => '1215531171',
    'message' => 'De WebGUI beheerknoppen voor dit gerelateerde product.'
  },
  'relatedproduct_loop' => {
    'lastUpdated' => '1215531203',
    'message' => 'Deze functie doorloopt alle producten die aan dit product verwant zijn.'
  },
  'relatedproduct_title' => {
    'lastUpdated' => '1215531219',
    'message' => 'De titel van het verwante product.'
  },
  'relatedproduct_url' => {
    'lastUpdated' => '1215531304',
    'message' => 'Het URL naar het gerelateerde product.'
  },
  'shortdesc' => {
    'lastUpdated' => '1215444660',
    'message' => 'Korte beschrijving'
  },
  'shortdesc description' => {
    'lastUpdated' => '1216587115',
    'message' => 'De korte beschrijving wordt getoond aan de gebruiker, zodat deze deze variant van het product kan aanschaffen. De lengte is beperkt tot 30 karakters.'
  },
  'specification_controls' => {
    'lastUpdated' => '1215531329',
    'message' => 'De WebGUI beheerknoppen voor deze specificatie.'
  },
  'specification_label' => {
    'lastUpdated' => '1215516801',
    'message' => 'Het label voor deze specificatie, bijvoorbeeld hoogte.'
  },
  'specification_loop' => {
    'lastUpdated' => '1153241514',
    'message' => 'De lijst van specificaties die aan dit product gerelateerd zijn '
  },
  'specification_specification' => {
    'lastUpdated' => '1215516761',
    'message' => 'De tekst van de specificatie zelf.'
  },
  'specification_units' => {
    'lastUpdated' => '1215516742',
    'message' => 'De eenheden van de specificaties, bijvoorbeeld meters.'
  },
  'specs' => {
    'lastUpdated' => '1215592517',
    'message' => 'Details'
  },
  'templateId' => {
    'lastUpdated' => '1189367395',
    'message' => 'De ID van het template dat wordt gebruikt om dit object (asset) weer te geven.'
  },
  'thank you message' => {
    'lastUpdated' => '1215516516',
    'message' => 'Bedankbericht'
  },
  'thank you message help' => {
    'lastUpdated' => '1215516708',
    'message' => 'Hier kan een bericht geschreven worden waarin de gebruiker bedankt wordt voor het kopen van een product op de site. Gebruikers kunnen hier nog steeds hun aankoop annuleren.'
  },
  'thumbnail1' => {
    'lastUpdated' => '1153241596',
    'message' => 'De URL naar de miniatuur van de eerste afbeelding die aan dit product is toegevoegd '
  },
  'thumbnail2' => {
    'lastUpdated' => '1153241611',
    'message' => 'De URL naar de miniatuur van de tweede afbeelding die aan dit product is toegevoegd '
  },
  'thumbnail3' => {
    'lastUpdated' => '1153241628',
    'message' => 'De URL naar de miniatuur van de derde afbeelding die aan dit product is toegevoegd '
  },
  'variant sku' => {
    'lastUpdated' => '1215592405',
    'message' => 'SKU'
  },
  'variant sku description' => {
    'lastUpdated' => '1215592485',
    'message' => 'Een unieke identificatie van deze variant van het product. Als deze gelijk is aan de identificatie van de voorraad software, kunnen deze gesynchroniseerd worden.'
  },
  'variant_controls' => {
    'lastUpdated' => '1215445842',
    'message' => 'Een taakbalk voor het bewerken, verwijderen of herorganiseren van deze variant.'
  },
  'variant_id' => {
    'lastUpdated' => '1222876408',
    'message' => 'De unieke identificatie van deze variant.'
  },
  'variant_loop' => {
    'lastUpdated' => '1215445797',
    'message' => 'Een functie die alle varianten van dit product doorloopt.'
  },
  'variant_price' => {
    'lastUpdated' => '1215445767',
    'message' => 'De prijs van deze variant'
  },
  'variant_quantity' => {
    'lastUpdated' => '1215445756',
    'message' => 'De hoeveelheid van deze variant'
  },
  'variant_sku' => {
    'lastUpdated' => '1215592501',
    'message' => 'De SKU van deze variant.'
  },
  'variant_title' => {
    'lastUpdated' => '1215445724',
    'message' => 'De titel of korte beschrijving van deze variant.'
  },
  'variant_weight' => {
    'lastUpdated' => '1215445739',
    'message' => 'Het gewicht van deze variant'
  },
  'variants' => {
    'lastUpdated' => '1215444670',
    'message' => 'Varianten'
  },
  'warranty' => {
    'lastUpdated' => '1189367417',
    'message' => 'De unieke identificatie (ID) van het storage object voor de garantie van het product.'
  },
  'warranty_icon' => {
    'lastUpdated' => '1215444691',
    'message' => 'Het URL naar het ikoontje van de garantie'
  },
  'warranty_label' => {
    'lastUpdated' => '1215444706',
    'message' => 'Het label voor het URL van de garantie'
  },
  'warranty_url' => {
    'lastUpdated' => '1215444729',
    'message' => 'Het URL waar de garantievoorwaarden gedownload kunnen worden.'
  },
  'weight' => {
    'lastUpdated' => '1213711958',
    'message' => 'Gewicht'
  },
  'weight description' => {
    'lastUpdated' => '1213711975',
    'message' => 'Het standaard gewicht van de variant'
  }
}
;

1;
